==> owncloud-8.2.9.tar.bz2: owncloud/apps/files/l10n/fi_FI.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Tallennustila ei ole käytettävissä",
    "Storage invalid" : "Virheellinen tallennustila",
    "Unknown error" : "Tuntematon virhe",
    "Could not move %s - File with this name already exists" : "Kohteen %s siirto ei onnistunut - Tiedosto samalla nimellä on jo olemassa",
    "Could not move %s" : "Kohteen %s siirto ei onnistunut",
    "Permission denied" : "Ei käyttöoikeutta",
    "The target folder has been moved or deleted." : "Kohdekansio on siirretty tai poistettu.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Nimi %s on jo käytössä kansiossa %s. Valitse toinen nimi.",
    "Error when creating the file" : "Virhe tiedostoa luotaessa",
    "Error when creating the folder" : "Virhe kansiota luotaessa",
    "Unable to set upload directory." : "Lähetyskansion asettaminen epäonnistui.",
    "Invalid Token" : "Virheellinen token",
    "No file was uploaded. Unknown error" : "Tiedostoa ei lähetetty. Tuntematon virhe",
    "There is no error, the file uploaded with success" : "Ei virheitä, tiedosto lähetettiin onnistuneesti",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Lähetetyn tiedoston koko ylittää php.ini-tiedoston upload_max_filesize-säännön:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lähetettävän tiedoston enimmäiskoko ylittää HTML-lomakkeessa määritellyn MAX_FILE_SIZE-säännön",
    "The uploaded file was only partially uploaded" : "Tiedoston lähetys onnistui vain osittain",
    "No file was uploaded" : "Yhtäkään tiedostoa ei lähetetty",
    "Missing a temporary folder" : "Tilapäiskansio puuttuu",
    "Failed to write to disk" : "Levylle kirjoitus epäonnistui",
    "Not enough storage available" : "Tallennustilaa ei ole riittävästi käytettävissä",
    "Upload failed. Could not find uploaded file" : "Lähetys epäonnistui. Lähettävää tiedostoa ei löydetty.",
    "Upload failed. Could not get file info." : "Lähetys epäonnistui. Lähettävää tiedostoa ei löydetty.",
    "Invalid directory." : "Virheellinen kansio.",
    "Files" : "Tiedostot",
    "All files" : "Kaikki tiedostot",
    "Favorites" : "Suosikit",
    "Home" : "Koti",
    "Close" : "Sulje",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kohdetta {filename} ei voi lähettää, koska se on joko kansio tai sen koko on 0 tavua",
    "Total file size {size1} exceeds upload limit {size2}" : "Yhteiskoko {size1} ylittää lähetysrajan {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ei riittävästi vapaata tilaa. Lähetyksesi koko on {size1}, mutta vain {size2} on jäljellä",
    "Upload cancelled." : "Lähetys peruttu.",
    "Could not get result from server." : "Tuloksien saaminen palvelimelta ei onnistunut.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Tiedoston lähetys on meneillään. Sivulta poistuminen nyt peruu tiedoston lähetyksen.",
    "Actions" : "Toiminnot",
    "Download" : "Lataa",
    "Rename" : "Nimeä uudelleen",
    "Delete" : "Poista",
    "Details" : "Tiedot",
    "Select" : "Valitse",
    "Pending" : "Odottaa",
    "Unable to determine date" : "Päivämäärän määrittäminen epäonnistui",
    "This operation is forbidden" : "Tämä toiminto on kielletty",
    "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
    "Error moving file." : "Virhe tiedostoa siirrettäessä.",
    "Error moving file" : "Virhe tiedostoa siirrettäessä",
    "Error" : "Virhe",
    "{new_name} already exists" : "{new_name} on jo olemassa",
    "Could not rename file" : "Tiedoston nimeäminen uudelleen epäonnistui",
    "Could not create file" : "Tiedoston luominen epäonnistui",
    "Could not create folder" : "Kansion luominen epäonnistui",
    "Error deleting file." : "Virhe tiedostoa poistaessa.",
    "No entries in this folder match '{filter}'" : "Mikään tässä kansiossa ei vastaa suodatusta '{filter}'",
    "Name" : "Nimi",
    "Size" : "Koko",
    "Modified" : "Muokattu",
    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
    "_%n file_::_%n files_" : ["%n tiedosto","%n tiedostoa"],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "You don’t have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai kansioiden luomiseen tähän sijaintiin",
    "_Uploading %n file_::_Uploading %n files_" : ["Lähetetään %n tiedosto","Lähetetään %n tiedostoa"],
    "New" : "Uusi",
    "\"{name}\" is an invalid file name." : "\"{name}\" on virheellinen tiedostonimi.",
    "File name cannot be empty." : "Tiedoston nimi ei voi olla tyhjä.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Käyttäjän {owner} tallennustila on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Your storage is full, files can not be updated or synced anymore!" : "Tallennustila on loppu, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Käyttäjän {owner} tallennustila on melkein täynnä ({usedSpacePercent} %)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Tallennustila on melkein loppu ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["vastaa '{filter}'","vastaa '{filter}'"],
    "Path" : "Polku",
    "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
    "Favorited" : "Lisätty suosikkeihin",
    "Favorite" : "Suosikki",
    "{newname} already exists" : "{newname} on jo olemassa",
    "Upload" : "Lähetä",
    "Text file" : "Tekstitiedosto",
    "New text file.txt" : "Uusi tekstitiedosto.txt",
    "Folder" : "Kansio",
    "New folder" : "Uusi kansio",
    "An error occurred while trying to update the tags" : "Tunnisteiden päivitystä yrittäessä tapahtui virhe",
    "A new file or folder has been <strong>created</strong>" : "Uusi tiedosto tai kansio on <strong>luotu</strong>",
    "A file or folder has been <strong>changed</strong>" : "Tiedostoa tai kansiota on <strong>muutettu</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Rajoita luomis- ja muutosilmoitukset <strong>omiin suosikkitiedostoihin</strong> <em>(Vain listaus)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Tiedosto tai kansio on <strong>poistettu</strong>",
    "A file or folder has been <strong>restored</strong>" : "Tiedosto tai kansio on <strong>palautettu</strong>",
    "You created %1$s" : "Loit kohteen %1$s",
    "%2$s created %1$s" : "%2$s loi kohteen %1$s",
    "%1$s was created in a public folder" : "%1$s luotiin julkiseen kansioon",
    "You changed %1$s" : "Muutit kohdetta %1$s",
    "%2$s changed %1$s" : "%2$s muutti kohdetta %1$s",
    "You deleted %1$s" : "Poistit kohteen %1$s",
    "%2$s deleted %1$s" : "%2$s poisti kohteen %1$s",
    "You restored %1$s" : "Palautit kohteen %1$s",
    "%2$s restored %1$s" : "%2$s palautti kohteen %1$s",
    "Changed by %2$s" : "Muuttanut %2$s",
    "Deleted by %2$s" : "Poistanut %2$s",
    "Restored by %2$s" : "Palauttanut %2$s",
    "%s could not be renamed as it has been deleted" : "Kohdetta %s ei voitu nimetä uudelleen, koska se on poistettu",
    "%s could not be renamed" : "kohteen %s nimeäminen uudelleen epäonnistui",
    "Upload (max. %s)" : "Lähetys (enintään %s)",
    "File handling" : "Tiedostonhallinta",
    "Maximum upload size" : "Lähetettävän tiedoston suurin sallittu koko",
    "max. possible: " : "suurin mahdollinen:",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "PHP-FPM:n ollessa käytössä tämän arvon tuleminen voimaan saattaa kestää viisi minuuttia tallennushetkestä.",
    "Save" : "Tallenna",
    "Can not be edited from here due to insufficient permissions." : "Ei muokattavissa täällä puutteellisten oikeuksien vuoksi.",
    "Settings" : "Asetukset",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Käytä tätä osoitetta <a href=\"%s\" target=\"_blank\">käyttääksesi tiedostojasi WebDAVin kautta</a>",
    "Cancel upload" : "Peru lähetys",
    "No files in here" : "Täällä ei ole tiedostoja",
    "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Select all" : "Valitse kaikki",
    "Upload too large" : "Lähetettävä tiedosto on liian suuri",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
    "Files are being scanned, please wait." : "Tiedostoja tarkistetaan, odota hetki.",
    "Currently scanning" : "Tutkitaan parhaillaan",
    "No favorites" : "Ei suosikkeja",
    "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0.tar.bz2: owncloud/apps/files/l10n/fi_FI.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Tallennustila ei ole käytettävissä",
    "Storage invalid" : "Virheellinen tallennustila",
    "Unknown error" : "Tuntematon virhe",
    "Unable to set upload directory." : "Lähetyskansion asettaminen epäonnistui.",
    "Invalid Token" : "Virheellinen token",
    "No file was uploaded. Unknown error" : "Tiedostoa ei lähetetty. Tuntematon virhe",
    "There is no error, the file uploaded with success" : "Ei virheitä, tiedosto lähetettiin onnistuneesti",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Lähetetyn tiedoston koko ylittää php.ini-tiedoston upload_max_filesize-säännön:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lähetettävän tiedoston enimmäiskoko ylittää HTML-lomakkeessa määritellyn MAX_FILE_SIZE-säännön",
    "The uploaded file was only partially uploaded" : "Tiedoston lähetys onnistui vain osittain",
    "No file was uploaded" : "Yhtäkään tiedostoa ei lähetetty",
    "Missing a temporary folder" : "Tilapäiskansio puuttuu",
    "Failed to write to disk" : "Levylle kirjoitus epäonnistui",
    "Not enough storage available" : "Tallennustilaa ei ole riittävästi käytettävissä",
    "The target folder has been moved or deleted." : "Kohdekansio on siirretty tai poistettu.",
    "Upload failed. Could not find uploaded file" : "Lähetys epäonnistui. Lähettävää tiedostoa ei löydetty.",
    "Upload failed. Could not get file info." : "Lähetys epäonnistui. Lähettävää tiedostoa ei löydetty.",
    "Invalid directory." : "Virheellinen kansio.",
    "Files" : "Tiedostot",
    "All files" : "Kaikki tiedostot",
    "Favorites" : "Suosikit",
    "Home" : "Koti",
    "Close" : "Sulje",
    "Upload cancelled." : "Lähetys peruttu.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kohdetta {filename} ei voi lähettää, koska se on joko kansio tai sen koko on 0 tavua",
    "Total file size {size1} exceeds upload limit {size2}" : "Yhteiskoko {size1} ylittää lähetysrajan {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ei riittävästi vapaata tilaa. Lähetyksesi koko on {size1}, mutta vain {size2} on jäljellä",
    "Error uploading file \"{fileName}\": {message}" : "Virhe lähettäessä tiedostoa \"{fileName}\": {message}",
    "Could not get result from server." : "Tuloksien saaminen palvelimelta ei onnistunut.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Tiedoston lähetys on meneillään. Sivulta poistuminen nyt peruu tiedoston lähetyksen.",
    "Actions" : "Toiminnot",
    "Download" : "Lataa",
    "Rename" : "Nimeä uudelleen",
    "Delete" : "Poista",
    "Disconnect storage" : "Katkaise yhteys tallennustilaan",
    "Unshare" : "Peru jakaminen",
    "Details" : "Tiedot",
    "Select" : "Valitse",
    "Pending" : "Odottaa",
    "Unable to determine date" : "Päivämäärän määrittäminen epäonnistui",
    "This operation is forbidden" : "Tämä toiminto on kielletty",
    "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
    "Could not move \"{file}\", target exists" : "Tiedoston \"{file}\" siirtäminen ei onnistunut, kohde on olemassa",
    "Could not move \"{file}\"" : "Tiedoston \"{file}\" siirtäminen ei onnistunut",
    "{newName} already exists" : "{newName} on jo olemassa",
    "Could not rename \"{fileName}\", it does not exist any more" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut, koska sitä ei ole enää olemassa",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
    "Could not rename \"{fileName}\"" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut",
    "Could not create file \"{file}\"" : "Tiedostoa \"{file}\" ei voitu luoda",
    "Could not create file \"{file}\" because it already exists" : "Tiedostoa \"{file}\" ei voitu luoda, koska se on jo olemassa",
    "Could not create folder \"{dir}\"" : "Kansiota \"{dir}\" ei voitu luoda",
    "Could not create folder \"{dir}\" because it already exists" : "Kansiota \"{dir}\" ei voitu luoda, koska se on jo olemassa",
    "Error deleting file \"{fileName}\"." : "Virhe poistaessa tiedostoa \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "Mikään tässä kansiossa ei vastaa suodatusta '{filter}'",
    "Name" : "Nimi",
    "Size" : "Koko",
    "Modified" : "Muokattu",
    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
    "_%n file_::_%n files_" : ["%n tiedosto","%n tiedostoa"],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "You don’t have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai kansioiden luomiseen tähän sijaintiin",
    "_Uploading %n file_::_Uploading %n files_" : ["Lähetetään %n tiedosto","Lähetetään %n tiedostoa"],
    "New" : "Uusi",
    "\"{name}\" is an invalid file name." : "\"{name}\" on virheellinen tiedostonimi.",
    "File name cannot be empty." : "Tiedoston nimi ei voi olla tyhjä.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Käyttäjän {owner} tallennustila on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Your storage is full, files can not be updated or synced anymore!" : "Tallennustila on loppu, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Käyttäjän {owner} tallennustila on melkein täynnä ({usedSpacePercent} %)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Tallennustila on melkein loppu ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["vastaa '{filter}'","vastaa '{filter}'"],
    "Path" : "Polku",
    "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
    "Favorited" : "Lisätty suosikkeihin",
    "Favorite" : "Suosikki",
    "Folder" : "Kansio",
    "New folder" : "Uusi kansio",
    "{newname} already exists" : "{newname} on jo olemassa",
    "Upload" : "Lähetä",
    "An error occurred while trying to update the tags" : "Tunnisteiden päivitystä yrittäessä tapahtui virhe",
    "A new file or folder has been <strong>created</strong>" : "Uusi tiedosto tai kansio on <strong>luotu</strong>",
    "A file or folder has been <strong>changed</strong>" : "Tiedostoa tai kansiota on <strong>muutettu</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Rajoita luomis- ja muutosilmoitukset <strong>omiin suosikkitiedostoihin</strong> <em>(Vain listaus)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Tiedosto tai kansio on <strong>poistettu</strong>",
    "A file or folder has been <strong>restored</strong>" : "Tiedosto tai kansio on <strong>palautettu</strong>",
    "You created %1$s" : "Loit kohteen %1$s",
    "%2$s created %1$s" : "%2$s loi kohteen %1$s",
    "%1$s was created in a public folder" : "%1$s luotiin julkiseen kansioon",
    "You changed %1$s" : "Muutit kohdetta %1$s",
    "%2$s changed %1$s" : "%2$s muutti kohdetta %1$s",
    "You deleted %1$s" : "Poistit kohteen %1$s",
    "%2$s deleted %1$s" : "%2$s poisti kohteen %1$s",
    "You restored %1$s" : "Palautit kohteen %1$s",
    "%2$s restored %1$s" : "%2$s palautti kohteen %1$s",
    "Changed by %2$s" : "Muuttanut %2$s",
    "Deleted by %2$s" : "Poistanut %2$s",
    "Restored by %2$s" : "Palauttanut %2$s",
    "Upload (max. %s)" : "Lähetys (enintään %s)",
    "File handling" : "Tiedostonhallinta",
    "Maximum upload size" : "Lähetettävän tiedoston suurin sallittu koko",
    "max. possible: " : "suurin mahdollinen:",
    "Save" : "Tallenna",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM:tä käyttäen muutoksien voimaantulossa saattaa kestää 5 minuuttia.",
    "Missing permissions to edit from here." : "Käyttöoikeudet eivät riitä tätä kautta muokkaamiseen.",
    "Settings" : "Asetukset",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Käytä tätä osoitetta <a href=\"%s\" target=\"_blank\">käyttääksesi tiedostojasi WebDAVin kautta</a>",
    "Cancel upload" : "Peru lähetys",
    "No files in here" : "Täällä ei ole tiedostoja",
    "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Select all" : "Valitse kaikki",
    "Upload too large" : "Lähetettävä tiedosto on liian suuri",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
    "No favorites" : "Ei suosikkeja",
    "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
    "Text file" : "Tekstitiedosto",
    "New text file.txt" : "Uusi tekstitiedosto.txt"
},
"nplurals=2; plural=(n != 1);");
